#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `syllapy` package."""

from string import punctuation

import syllapy


def test_simple():
    assert 1 == syllapy.count("dog!!!!!")


def test_none():
    assert 0 == syllapy.count(None)


def test_bool():
    assert 0 == syllapy.count(True)


def test_int():
    assert 0 == syllapy.count(2)


def test_empty():
    assert 0 == syllapy.count("")


def test_space():
    assert 0 == syllapy.count(" ")


def test_punctuation_only():
    for p in punctuation:
        assert 0 == syllapy.count(p)


def test_not_in_dict():
    assert 4 == syllapy.count('ostentatious')


def test_in_dict():
    assert 2 == syllapy.count('because')
    assert 2 == syllapy.count('woman')
    assert 5 == syllapy.count('international')



# -*- coding: utf-8 -*-

"""Top-level package for SyllaPy."""

__author__ = """Michael Holtzscher"""
__email__ = 'mholtz@protonmail.com'
__version__ = '0.2.1'

from string import punctuation
from .data_loader import load_dict
import logging

log = logging.getLogger(__name__)

# load the known words dictionary
word_dict = load_dict()


def count(word):
    """Returns number of syllables in a word. If the word is None, not a string, or empty then returns 0."""
    if not isinstance(word, str):
        return 0
    word = word.strip().lower().strip(punctuation)
    if len(word) == 0:
        return 0
    if word in word_dict:
        return word_dict[word]
    log.info("'%s' not found in known word list.", word)
    return _syllables(word)


def _syllables(word):
    syllable_count = 0
    vowels = 'aeiouy'
    if word[0] in vowels:
        syllable_count += 1
    for index in range(1, len(word)):
        if word[index] in vowels and word[index - 1] not in vowels:
            syllable_count += 1
    if word.endswith('e'):
        syllable_count -= 1
    if word.endswith('le') and len(word) > 2 and word[-3] not in vowels:
        syllable_count += 1
    if syllable_count == 0:
        syllable_count += 1
    return syllable_count



import csv

import pkg_resources


def load_dict():
    file_name = 'data.csv'
    file_path = pkg_resources.resource_filename(__name__, file_name)
    words = {}
    with open(file_path, newline='') as csv_file:
        reader = csv.reader(csv_file, delimiter=',')
        for row in reader:
            words[row[0]] = int(row[1])
    return words
